@@ -6,12 +6,11 @@
 #' It is used by the \code{get_census_api} function. The user should not need to call this 
 #' function directly.
 #'
-#' @param data_url URL root of the API, including the question mark, 
-#'  e.g., \code{"https://api.census.gov/data/2010/dec/sf1?"}.
-#' @param key A required character object containing user's Census API key, 
-#'  which can be requested \href{https://api.census.gov/data/key_signup.html}{here}.
+#' @inheritParams get_census_data
+#' @param data_url URL root of the API,
+#'  e.g., \code{"https://api.census.gov/data/2020/dec/pl"}.
 #' @param get A character vector of variables to get, 
-#'  e.g., \code{c("P005003","P005004","P005005", "P005006")}.
+#'  e.g., \code{c("P2_005N", "P2_006N", "P2_007N", "P2_008N")}.
 #'  If there are more than 50 variables, then function will automatically 
 #'  split variables into separate queries.
 #' @param region Character object specifying which region to obtain data for.
@@ -22,15 +21,21 @@
 #'  If unsuccessful, function prints the URL query that was constructed.
 #'
 #' @examples
-#' \dontrun{try(get_census_api_2(data_url = "https://api.census.gov/data/2010/dec/sf1?", key = "...", 
-#' get = c("P005003","P005004","P005005", "P005006"), region = "for=county:*&in=state:34"))}
+#' \dontrun{try(get_census_api_2(data_url = "https://api.census.gov/data/2020/dec/pl",
+#' get = c("P2_005N", "P2_006N", "P2_007N", "P2_008N"), region = "for=county:*&in=state:34"))}
 #' 
 #' @references
 #' Based on code authored by Nicholas Nagle, which is available 
 #' \href{https://rstudio-pubs-static.s3.amazonaws.com/19337_2e7f827190514c569ea136db788ce850.html}{here}.
 #'
 #' @keywords internal
-get_census_api_2 <- function(data_url, key, get, region, retry = 3){
+get_census_api_2 <- function(
+    data_url,
+    key = Sys.getenv("CENSUS_API_KEY"),
+    get,
+    region,
+    retry = 3
+){
   if(length(get) > 1) {
     get <- paste(get, collapse=',', sep='')
   }
